@@ -8,7 +8,7 @@ use XML::Genx::Simple;
 
 use base 'XML::SAX::Base';
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 sub new {
     my $class = shift;
@@ -197,8 +197,37 @@ what SAX is.
 Essentially, this is just a wrapper over L<XML::Genx>, mapping calls
 from SAX to genx.
 
+=head1 METHODS
+
+The following methods are defined as part of the usual
+L<XML::SAX::Base> interface.
+
+=over 4
+
+=item new()
+
+=item characters()
+
+=item comment()
+
+=item end_document()
+
+=item end_element()
+
+=item end_prefix_mapping()
+
+=item processing_instruction()
+
+=item start_document()
+
+=item start_element()
+
+=item start_prefix_mapping()
+
+=back
+
 =head1 VERSION
 
-@(#) $Id: SAXWriter.pm 728 2005-07-31 00:08:43Z dom $
+@(#) $Id: SAXWriter.pm 878 2005-09-02 19:37:19Z dom $
 
 =cut
